abacusai.user — AbacusAI documentation

# abacusai.user

## Classes

`User` | An Abacus.AI User

## Module Contents

class abacusai.user.User(client, name=None, email=None, createdAt=None, status=None, organizationGroups={})

  Bases: `abacusai.return_class.AbstractApiClass`

  An Abacus.AI User

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The User’s name.

    - email (str) – The User’s primary email address.

    - createdAt (str) – The date and time when the user joined Abacus.AI.

    - status (str) – ACTIVE when the user has accepted an invite to join the organization, else INVITED.

    - organizationGroups (OrganizationGroup) – List of Organization Groups this user belongs to.

  name
  email
  created_at
  status
  organization_groups
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict